import type { AbiParameter, AbiParametersToPrimitiveTypes } from 'abitype';
import { type AbiDecodingDataSizeTooSmallErrorType, type AbiDecodingZeroDataErrorType, type InvalidAbiDecodingTypeErrorType } from '../../errors/abi.js';
import type { Hex } from '../../types/misc.js';
import { type ChecksumAddressErrorType } from '../address/getAddress.js';
import { type SizeErrorType } from '../data/size.js';
import { type SliceErrorType } from '../data/slice.js';
import { type TrimErrorType } from '../data/trim.js';
import { type HexToBigIntErrorType, type HexToBoolErrorType, type HexToNumberErrorType, type HexToStringErrorType } from '../encoding/fromHex.js';
import type { ErrorType } from '../../errors/utils.js';
import { type GetArrayComponentsErrorType } from './encodeAbiParameters.js';
export type DecodeAbiParametersReturnType<TParams extends readonly AbiParameter[] | readonly unknown[] = readonly AbiParameter[]> = AbiParametersToPrimitiveTypes<TParams extends readonly AbiParameter[] ? TParams : AbiParameter[]>;
export type DecodeAbiParametersErrorType = AbiDecodingDataSizeTooSmallErrorType | AbiDecodingZeroDataErrorType | DecodeParamsErrorType | SizeErrorType | ErrorType;
export declare function decodeAbiParameters<const TParams extends readonly AbiParameter[] | readonly unknown[]>(params: TParams, data: Hex): DecodeAbiParametersReturnType<TParams>;
type DecodeParamsErrorType = DecodeParamErrorType | SizeErrorType | ErrorType;
type DecodeParamErrorType = DecodeArrayErrorType | DecodeTupleErrorType | DecodeStringErrorType | DecodeBytesErrorType | DecodeNumberErrorType | DecodeAddressErrorType | DecodeBoolErrorType | InvalidAbiDecodingTypeErrorType | ErrorType;
type DecodeAddressErrorType = ChecksumAddressErrorType | SliceErrorType | ErrorType;
type DecodeArrayErrorType = HexToNumberErrorType | SliceErrorType | ErrorType;
type DecodeBoolErrorType = HexToBoolErrorType | ErrorType;
type DecodeBytesErrorType = HexToNumberErrorType | SliceErrorType | ErrorType;
type DecodeNumberErrorType = HexToBigIntErrorType | HexToNumberErrorType | ErrorType;
type DecodeStringErrorType = HexToNumberErrorType | HexToStringErrorType | SliceErrorType | TrimErrorType | ErrorType;
type DecodeTupleErrorType = HasDynamicChildErrorType | HexToNumberErrorType | SliceErrorType | ErrorType;
type HasDynamicChildErrorType = GetArrayComponentsErrorType | ErrorType;
export {};
//# sourceMappingURL=decodeAbiParameters.d.ts.map